==> pyasic-0.54.8.tar.gz: pyasic-0.54.8/pyasic/miners/whatsminer/btminer/M3X/M30S_Plus_Plus.py <==
# ------------------------------------------------------------------------------
#  Copyright 2022 Upstream Data Inc                                            -
#                                                                              -
#  Licensed under the Apache License, Version 2.0 (the "License");             -
#  you may not use this file except in compliance with the License.            -
#  You may obtain a copy of the License at                                     -
#                                                                              -
#      http://www.apache.org/licenses/LICENSE-2.0                              -
#                                                                              -
#  Unless required by applicable law or agreed to in writing, software         -
#  distributed under the License is distributed on an "AS IS" BASIS,           -
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.    -
#  See the License for the specific language governing permissions and         -
#  limitations under the License.                                              -
# ------------------------------------------------------------------------------

from pyasic.miners.backends import M3X
from pyasic.miners.models import (
    M30SPlusPlusV10,
    M30SPlusPlusV20,
    M30SPlusPlusVE30,
    M30SPlusPlusVE40,
    M30SPlusPlusVE50,
    M30SPlusPlusVF40,
    M30SPlusPlusVG30,
    M30SPlusPlusVG40,
    M30SPlusPlusVG50,
    M30SPlusPlusVH10,
    M30SPlusPlusVH20,
    M30SPlusPlusVH30,
    M30SPlusPlusVH40,
    M30SPlusPlusVH50,
    M30SPlusPlusVH60,
    M30SPlusPlusVH70,
    M30SPlusPlusVH80,
    M30SPlusPlusVH90,
    M30SPlusPlusVH100,
    M30SPlusPlusVJ20,
    M30SPlusPlusVJ30,
)


class BTMinerM30SPlusPlusV10(M3X, M30SPlusPlusV10):
    pass


class BTMinerM30SPlusPlusV20(M3X, M30SPlusPlusV20):
    pass


class BTMinerM30SPlusPlusVE30(M3X, M30SPlusPlusVE30):
    pass


class BTMinerM30SPlusPlusVE40(M3X, M30SPlusPlusVE40):
    pass


class BTMinerM30SPlusPlusVE50(M3X, M30SPlusPlusVE50):
    pass


class BTMinerM30SPlusPlusVF40(M3X, M30SPlusPlusVF40):
    pass


class BTMinerM30SPlusPlusVG30(M3X, M30SPlusPlusVG30):
    pass


class BTMinerM30SPlusPlusVG40(M3X, M30SPlusPlusVG40):
    pass


class BTMinerM30SPlusPlusVG50(M3X, M30SPlusPlusVG50):
    pass


class BTMinerM30SPlusPlusVH10(M3X, M30SPlusPlusVH10):
    pass


class BTMinerM30SPlusPlusVH20(M3X, M30SPlusPlusVH20):
    pass


class BTMinerM30SPlusPlusVH30(M3X, M30SPlusPlusVH30):
    pass


class BTMinerM30SPlusPlusVH40(M3X, M30SPlusPlusVH40):
    pass


class BTMinerM30SPlusPlusVH50(M3X, M30SPlusPlusVH50):
    pass


class BTMinerM30SPlusPlusVH60(M3X, M30SPlusPlusVH60):
    pass


class BTMinerM30SPlusPlusVH70(M3X, M30SPlusPlusVH70):
    pass


class BTMinerM30SPlusPlusVH80(M3X, M30SPlusPlusVH80):
    pass


class BTMinerM30SPlusPlusVH90(M3X, M30SPlusPlusVH90):
    pass


class BTMinerM30SPlusPlusVH100(M3X, M30SPlusPlusVH100):
    pass


class BTMinerM30SPlusPlusVJ20(M3X, M30SPlusPlusVJ20):
    pass


class BTMinerM30SPlusPlusVJ30(M3X, M30SPlusPlusVJ30):
    pass

==> pyasic-0.64.1.tar.gz: pyasic-0.64.1/pyasic/miners/whatsminer/btminer/M3X/M30S_Plus_Plus.py <==
# ------------------------------------------------------------------------------
#  Copyright 2022 Upstream Data Inc                                            -
#                                                                              -
#  Licensed under the Apache License, Version 2.0 (the "License");             -
#  you may not use this file except in compliance with the License.            -
#  You may obtain a copy of the License at                                     -
#                                                                              -
#      http://www.apache.org/licenses/LICENSE-2.0                              -
#                                                                              -
#  Unless required by applicable law or agreed to in writing, software         -
#  distributed under the License is distributed on an "AS IS" BASIS,           -
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.    -
#  See the License for the specific language governing permissions and         -
#  limitations under the License.                                              -
# ------------------------------------------------------------------------------

from pyasic.miners.backends import M3X
from pyasic.miners.device.models import (
    M30SPlusPlusV10,
    M30SPlusPlusV20,
    M30SPlusPlusVE30,
    M30SPlusPlusVE40,
    M30SPlusPlusVE50,
    M30SPlusPlusVF40,
    M30SPlusPlusVG30,
    M30SPlusPlusVG40,
    M30SPlusPlusVG50,
    M30SPlusPlusVH10,
    M30SPlusPlusVH20,
    M30SPlusPlusVH30,
    M30SPlusPlusVH40,
    M30SPlusPlusVH50,
    M30SPlusPlusVH60,
    M30SPlusPlusVH70,
    M30SPlusPlusVH80,
    M30SPlusPlusVH90,
    M30SPlusPlusVH100,
    M30SPlusPlusVJ20,
    M30SPlusPlusVJ30,
)


class BTMinerM30SPlusPlusV10(M3X, M30SPlusPlusV10):
    pass


class BTMinerM30SPlusPlusV20(M3X, M30SPlusPlusV20):
    pass


class BTMinerM30SPlusPlusVE30(M3X, M30SPlusPlusVE30):
    pass


class BTMinerM30SPlusPlusVE40(M3X, M30SPlusPlusVE40):
    pass


class BTMinerM30SPlusPlusVE50(M3X, M30SPlusPlusVE50):
    pass


class BTMinerM30SPlusPlusVF40(M3X, M30SPlusPlusVF40):
    pass


class BTMinerM30SPlusPlusVG30(M3X, M30SPlusPlusVG30):
    pass


class BTMinerM30SPlusPlusVG40(M3X, M30SPlusPlusVG40):
    pass


class BTMinerM30SPlusPlusVG50(M3X, M30SPlusPlusVG50):
    pass


class BTMinerM30SPlusPlusVH10(M3X, M30SPlusPlusVH10):
    pass


class BTMinerM30SPlusPlusVH20(M3X, M30SPlusPlusVH20):
    pass


class BTMinerM30SPlusPlusVH30(M3X, M30SPlusPlusVH30):
    pass


class BTMinerM30SPlusPlusVH40(M3X, M30SPlusPlusVH40):
    pass


class BTMinerM30SPlusPlusVH50(M3X, M30SPlusPlusVH50):
    pass


class BTMinerM30SPlusPlusVH60(M3X, M30SPlusPlusVH60):
    pass


class BTMinerM30SPlusPlusVH70(M3X, M30SPlusPlusVH70):
    pass


class BTMinerM30SPlusPlusVH80(M3X, M30SPlusPlusVH80):
    pass


class BTMinerM30SPlusPlusVH90(M3X, M30SPlusPlusVH90):
    pass


class BTMinerM30SPlusPlusVH100(M3X, M30SPlusPlusVH100):
    pass


class BTMinerM30SPlusPlusVJ20(M3X, M30SPlusPlusVJ20):
    pass


class BTMinerM30SPlusPlusVJ30(M3X, M30SPlusPlusVJ30):
    pass
